@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import imp
+import importlib.util
 import os
 
 from neutron_lib.api import definitions
@@ -23,7 +23,7 @@ from neutron_lib.tests import _base as test_base
 def assert_bool(tester, attribute, attribute_dict, keyword, value):
     tester.assertIsInstance(
         value, bool,
-        '%s must be a boolean for %s.' % (keyword, attribute))
+        '{} must be a boolean for {}.'.format(keyword, attribute))
 
 
 def assert_converter(tester, attribute, attribute_dict, keyword, value):
@@ -45,12 +45,13 @@ def assert_converter(tester, attribute, attribute_dict, keyword, value):
 
 def assert_true(tester, attribute, attribute_dict, keyword, value):
     tester.assertTrue(
-        value, '%s must be True for %s.' % (keyword, attribute))
+        value, '{} must be True for {}.'.format(keyword, attribute))
 
 
 def assert_validator(tester, attribute, attribute_dict, keyword, value):
     tester.assertIn(list(value)[0], validators.validators,
-                    '%s is not a known validator for %s.' % (value, attribute))
+                    '{} is not a known validator for {}.'.format(
+                        value, attribute))
 
 
 ASSERT_FUNCTIONS = {
@@ -79,7 +80,7 @@ class DefinitionBaseTestCase(test_base.BaseTestCase):
     extension_attributes = ()
 
     def setUp(self):
-        super(DefinitionBaseTestCase, self).setUp()
+        super().setUp()
         if not self.extension_module:
             self.fail("Missing extension module definition.")
         self.alias = self.extension_module.ALIAS
@@ -205,6 +206,14 @@ class DefinitionBaseTestCase(test_base.BaseTestCase):
             self.assertIn(ext, base.KNOWN_EXTENSIONS,
                           'Optional extension is unknown, check for typos.')
 
+    def _load_module(self, name, path):
+        module_spec = importlib.util.spec_from_file_location(
+            name, path
+        )
+        module = importlib.util.module_from_spec(module_spec)
+        module_spec.loader.exec_module(module)
+        return module
+
     def test_all_api_definitions_list(self):
         # ensure _ALL_API_DEFINITIONS contains all public api-defs
         ext_aliases = []
@@ -213,7 +222,7 @@ class DefinitionBaseTestCase(test_base.BaseTestCase):
             mod_name, file_ext = os.path.splitext(os.path.split(f)[-1])
             ext_path = os.path.join(api_def_path, f)
             if file_ext.lower() == '.py' and not mod_name.startswith('_'):
-                mod = imp.load_source(mod_name, ext_path)
+                mod = self._load_module(mod_name, ext_path)
                 ext_alias = getattr(mod, 'ALIAS', None)
                 if not ext_alias:
                     continue
